#!/bin/ksh
#
#######################################################################################
# UNIX SHELL program to start/end/status/help NetView for OS/390 services             #
#######################################################################################
# Licensed Materials - Property of Tivoli Systems                     #
# 5697-ENV (c) Copyright Tivoli Systems 1999                          #
# All rights reserved.                                                #
#                                                                     #
# US Government Users Restricted Rights - Use, duplication or         #
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.   #
#######################################################################################
#######################################################################################
#
# Shell Switches
# uncomment following set -x command for debug pupose
# set -x
#######################################################################################
set -e
PRODUCT="NetView for OS/390"

######################################################################################
# Start methods
# Check to see if this script already started the process. If not start the process
# and create the necessary *.pid file(s)
######################################################################################
start()
{
        checkProcess
        if [ "$isSnmpRunning" -eq 1 ]
        then
             echo "Snmp is already running."
             echo "Exiting..."
             exit1
        fi
        if [ "$isWebRunning" -eq 1 ]
        then
             echo "Webserver is already running."
             exit1
        fi
        echo "Starting snmp...."
        echo "Starting webserver..."
        ###############################################################################
        # Now build the command, echo it & then execute
        ###############################################################################
        CMDSTR1=$NETVIEW_HOME/bin/snmpsrvr.sh
 	echo $CMDSTR1
        CMDSTR2=$NETVIEW_HOME/bin/websrvr.sh
 	echo $CMDSTR2

        $CMDSTR1 &
	jobs -p > $NETVIEW_TMP/snmpserver.pid
        sleep 10
        $CMDSTR2 &
        jobs -p > $NETVIEW_TMP/webserver.pid
}

startsnmp()
{
        checkProcessSnmp
        if [ "$isSnmpRunning" -eq 1 ]
        then
             echo "Snmp is already running."
             exit1
        fi
        echo "Starting snmp..."

        ###############################################################################
        # Now build the command echo, it & then execute
        ###############################################################################
        CMDSTR1=$NETVIEW_HOME/bin/snmpsrvr.sh
 	echo $CMDSTR1
        $CMDSTR1 &
	jobs -p > $NETVIEW_TMP/snmpserver.pid
}

startweb()
{
        checkProcessWeb
        if [ "$isWebRunning" -eq 1 ]
        then
             echo "Webserver is already running."
             exit1
        fi
        echo "Starting webserver...."

        ###############################################################################
        # Now build the command, echo it & then execute
        ###############################################################################
        CMDSTR2=$NETVIEW_HOME/bin/websrvr.sh
 	echo $CMDSTR2
        $CMDSTR2 &
	jobs -p > $NETVIEW_TMP/webserver.pid
}



#######################################################################################
# End methods
# Pull the pid from the appropriate *.pid file and kill the process
#######################################################################################
end()
{
        endsnmp
        endweb
}

endsnmp()
{    
        set -A parray `cat $NETVIEW_TMP/snmpserver.pid 2>/dev/null | awk '{print $1}'`

	if [ ${#parray[*]} -gt 0 ]
        then
		echo "Stopping snmpserver..."
                rm  $NETVIEW_TMP/snmpserver.pid 2>/dev/null
		kill -9 ${parray[*]} 2>/dev/null
                echo "We just killed ${parray[*]}"
	fi
}

endweb()
{
        set -A parray `cat $NETVIEW_TMP/webserver.pid 2>/dev/null | awk '{print $1}'`

	if [ ${#parray[*]} -gt 0 ]
        then
		echo "Stopping webserver..."
                rm  $NETVIEW_TMP/webserver.pid 2>/dev/null
		kill -9 ${parray[*]} 2>/dev/null
                echo "We just killed ${parray[*]}"
	fi
}

#######################################################################################
# restart methods
# End the process, sleep a bit and start the process back up
#######################################################################################
restart()
{
  end
  sleep 1
  start
}

restartsnmp()
{
  endsnmp
  sleep 1
  startsnmp
}

restartweb()
{
  endweb
  sleep 1
  startweb
}


#######################################################################################
# checkProcess methods
# Used to determine whether or not the specified process has been started by this script
# Sets isRunning,isWebRunning, or is isSnmpRunning to 0 or 1
#######################################################################################
checkProcess()
{
  checkProcessSnmp
  checkProcessWeb
}

checkProcessSnmp()
{
        isSnmpRunning=1

	set -A parray `cat $NETVIEW_TMP/snmpserver.pid 2>/dev/null | awk '{print $1}'`
        if [ ${#parray[*]} -eq 0 ]
	  then
            isSnmpRunning=0
	fi	
}

checkProcessWeb()
{
        isWebRunning=1

	set -A parray `cat $NETVIEW_TMP/webserver.pid 2>/dev/null | awk '{print $1}'`
        if [ ${#parray[*]} -eq 0 ]
	  then
            isWebRunning=0
	fi	
}

######################################################################################
# Premature exit
######################################################################################
exit1()
{
  echo "$0 exiting prematurely..."
  exit 1
}

#######################################################################################
# Provide help if arguments are not accounted for
#######################################################################################
help()
{
        echo "nvsrvc [start] { webserver snmpserver } [end] { webserver snmpserver } [restart] { webserver snmpserver } [help] "
        echo "nvsrvc - will default to help. "
}

#######################################################################################
# Process main arguments
#######################################################################################
echo "Starting nvsrvc..."

if [ $# -eq 0 ]
then
        help
        exit 0
fi

if [ -z "${NETVIEW_HOME}" ]
then
   #echo "The enviornment variable NETVIEW_HOME must be set for this script to run properly..."
   #exit 0
   NETVIEW_HOME=`pwd | sed -e "s/\/bin//"`
   export NETVIEW_HOME
   echo "NETVIEW_HOME has been set to $NETVIEW_HOME"        
fi

JAVA_HOME=${NETVIEW_HOME}/jvm/jre
JAVA=${JAVA_HOME}/bin/java

if [ ! -x $JAVA ]
then
    echo "Unable to find: $JAVA."
    exit1
fi    

if [ -z "$NETVIEW_TMP" ]
then
    export NETVIEW_TMP=$NETVIEW_HOME/logs
    echo "The temp directory has been set to $NETVIEW_TMP."
fi

if [ ! -d $NETVIEW_TMP ];then
  mkdir $NETVIEW_TMP
  echo "Creating $NETVIEW_TMP" 
fi
 

case $1 in
  h*)
     help
     exit 0
     ;;
  start)
     if [ "$2" ]
     then
       case $2 in
         webserver)
           startweb
           exit 0
           ;;
         snmpserver)
           startsnmp  
           exit 0
           ;;
          *)
           help
           exit 0
           ;;
        esac
     else
       start
       exit 0
     fi
     ;;  
  end)
     if [ "$2" ]
     then
       case $2 in
         webserver)
           endweb
           exit 0
           ;;
          snmpserver)
           endsnmp  
           exit 0
           ;;
          *)
           help
           exit 0
           ;;
        esac
     else
       end
       exit 0
     fi
     ;;
  restart)
     if [ "$2" ]
     then
       case $2 in
         webserver)
           restartweb
           exit 0
           ;;
         snmpserver)
           restartsnmp  
           exit 0
           ;;
          *)
           help
           exit 0
           ;;
        esac
     else
       restart
       exit 0
     fi
     ;; 
  *)
     help
     exit 0
     ;;
esac
echo "Goodbye!"
#######################################################################################
# Done
#######################################################################################
