#!/bin/ksh
#
#######################################################################
# UNIX SHELL program to start NetView for OS/390 websrvr              #
#######################################################################
# Licensed Materials - Property of Tivoli Systems                     #
# 5697-ENV (c) Copyright Tivoli Systems 1999                          #
# All rights reserved.                                                #
#                                                                     #
# US Government Users Restricted Rights - Use, duplication or         #
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.   #
#######################################################################
#######################################################################
#
##Shell Switches
##
##uncomment following set -x command for debug pupose
#set -x


######################################################################
# Exit prematurely
######################################################################
exit1()
{
  echo "$0 exiting prematurely..."
  exit 1
}


#######################################################################
# Temporary fix for AIX problem use option
#######################################################################
if [ "`uname`" =  "AIX" ] ; then
    echo "Disable JIT for `uname`."
    export JAVA_COMPILER=NONE
fi

######################################################################
# Set NetView Home and Jetty Home
######################################################################

NETVIEW_TMP=${NETVIEW_HOME}/log

if [ ! -d $NETVIEW_TMP ];then
  mkdir $NETVIEW_TMP
  echo "Creating $NETVIEW_TMP" 
fi

JAVA_HOME=${NETVIEW_HOME}/jvm/jre
JAVA=${JAVA_HOME}/bin/java

if [[ ! -x ${JAVA} ]]
then
   if [ ! -x "$TESTJAVA" ] ; then
            echo "Unable to find: $JAVA."
            exit1
   fi 
   JAVA=${TESTJAVA}
fi
                 
JAVA_OPTIONS=

JETTY_HOME=${NETVIEW_HOME}/www

######################################################################
# Get the action & configs
######################################################################
CONFIGS=$1 $2 $3 $4 $5 $6 $7 $8 $9
if [[ -z ${CONFIGS} ]] 
then 
   CONFIGS=${JETTY_HOME}/conf/jetty.xml
fi

if [[ -z ${JETTY_LOG} ]]
then
   JETTY_LOG=${NETVIEW_HOME}/log
   if [ ! -d $JETTY_LOG ];then
     mkdir $JETTY_LOG
     echo "Creating $JETTY_LOG" 
   fi
fi

######################################################################
# Find a location for the jetty console
######################################################################
if [ -z "$JETTY_CONSOLE" ]
then
   JETTY_CONSOLE=/dev/console
fi

######################################################################
# Classpath
#CP=${CP}:${JETTY_HOME}/lib/com.tivoli.netview.jar
######################################################################
CP=${JETTY_HOME}/lib/javax.servlet.jar
CP=${CP}:${JETTY_HOME}/lib/org.mortbay.jetty.jar
CP=${CP}:${JETTY_HOME}/lib/javax.xml.jaxp.jar
CP=${CP}:${JETTY_HOME}/lib/org.apache.jasper.jar 
CP=${CP}:${JETTY_HOME}/lib/org.apache.crimson.jar 
CP=${CP}:${JETTY_HOME}/lib/com.sun.net.ssl.jar
if [ -f $JAVA_HOME/lib/tools.jar ]
then
#  CP=${CP}:${JAVA_HOME}/lib/tools.jar
   CP=${CP}:${JAVA_HOME}/lib/
fi

######################################################################
# when log4j Category class is loaded,
# classpath is searched for a log4j.properties file
# if one is found it will be read to  default log4j configuration
######################################################################
if [ -f "${JETTY_HOME}/classes/log4j.properties" ] 
then
   CP=${CP}:${JETTY_HOME}/classes
fi

######################################################################
# add Jetty properties to Java VM options
######################################################################
JAVA_OPTIONS="-Xmx64m -Dnetview.home=${NETVIEW_HOME} -Djetty.home=${JETTY_HOME} -Djetty.log=${JETTY_LOG} -DNV_RELEASE=NETVIEW_H -cp ${CP} ${JAVA_OPTIONS}"

######################################################################
# command to run Jetty
######################################################################
RUN_CMD="${JAVA} ${JAVA_OPTIONS} org.mortbay.jetty.Server ${CONFIGS}"


######################################################################
# Do the action
######################################################################

echo "Running Jetty... "
echo "Started Jetty at `date`" >> ${JETTY_LOG}/jetty.out

exec ${RUN_CMD}








